summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorptmcg <ptmcg@austin.rr.com>2022-06-17 01:34:13 -0500
committerptmcg <ptmcg@austin.rr.com>2022-06-17 01:34:13 -0500
commitcbbbbc9022c179c8d710c7009b0dd587eeb338d4 (patch)
treec4ca6549e59c0b3c4931842c3fecdca391e31ea1
parent89b9965f7a9c28a6fcb6189892e9e52b3dd09083 (diff)
downloadpyparsing-git-cbbbbc9022c179c8d710c7009b0dd587eeb338d4.tar.gz
Docstring cleanups in col and lineno functions
-rw-r--r--pyparsing/util.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/pyparsing/util.py b/pyparsing/util.py
index 6e95d58..43bacda 100644
--- a/pyparsing/util.py
+++ b/pyparsing/util.py
@@ -42,7 +42,7 @@ def col(loc: int, strg: str) -> int:
Note: the default parsing behavior is to expand tabs in the input string
before starting the parsing process. See
- :class:`ParserElement.parseString` for more
+ :class:`ParserElement.parse_string` for more
information on parsing strings containing ``<TAB>`` s, and suggested
methods to maintain a consistent view of the parsed string, the parse
location, and line and column positions within the parsed string.
@@ -57,7 +57,7 @@ def lineno(loc: int, strg: str) -> int:
The first line is number 1.
Note - the default parsing behavior is to expand tabs in the input string
before starting the parsing process. See :class:`ParserElement.parseString`
for more information on parsing strings containing ``<TAB>`` s, and
suggested methods to maintain a consistent view of the parsed string, the
parse location, and line and column positions within the parsed string.
@@ -57,7 +57,7 @@ def lineno(loc: int, strg: str) -> int:
The first line is number 1.
Note - the default parsing behavior is to expand tabs in the input string
- before starting the parsing process. See :class:`ParserElement.parseString`
+ before starting the parsing process. See :class:`ParserElement.parse_string`
for more information on parsing strings containing ``<TAB>`` s, and
suggested methods to maintain a consistent view of the parsed string, the